<?php

/**
 * Image Manipulation
 * Motion-Effect
 * 
 * @author SELFPHP OHG
 * @copyright 2009, SELFPHP OHG
 * @license BSD License
 * @link http://www.selfphp.de 
 * 
 * Example 1:
 * $motion = new ImageManipulation( "pictures/DSC_0233.png", 150, 100 );
 * $motion -> createMotion( 5, "ffffff", false, 70 );
 * $motion -> createImage( "dsc-small.jpg" );
 * 
 * Example 2:
 * $motion = new ImageManipulation( "pictures/DSC_0233.png", 150, 100 );
 * $motion -> createMotion( 5, "ffffff" );
 * $motion -> createImage( "dsc-small.jpg" );
 * 
 */

class ImageManipulation {

	/**
     * @var string Dateipfad Original-Bild
     */
    private $resource = NULL;
    
    /**
     * @var image Thumbnail
     */
    private $imageNew = NULL;
    
    /**
     * @var integer Breite Thumbnail
     */
    private $widthNew = NULL;
    
    /**
     * @var integer Hhe Thumbnail
     */
    private $heightNew = NULL;

    
    /*
	 * Constructor 
	 * 
	 * @param	string	$resourceFile	Dateipfad Original-Bild
	 * @param	integer	$width			Bildbreite Thumbnail
	 * @param	integer	$height			Bildhhe Thumbnail
	 * 
	 */
    function __construct( $resourceFile, $width, $height ) {
		
    	if ( file_exists ( $resourceFile ) == TRUE ){
    		
		    $this->resource = $resourceFile;
		    
		    $this->widthNew = $width;
		    
		    $this->heightNew = $height;
		    
		    $this->createThumbnail ();
		    
    	}
	
	}
	
	/**
	 * Thumbnail erstellen
	 */
	private function createThumbnail( ){
	
		$info = getimagesize( $this->resource );
		
		if ( $info[2] == 1 ){
			// GIF
			$image = imagecreatefromgif( $this->resource );
		}
		elseif ( $info[2] == 2 ){
			// JPG
			$image = imagecreatefromjpeg( $this->resource );
		}
		elseif ( $info[2] == 3 ){
			// PNG
			$image = imagecreatefrompng( $this->resource );
		}
		else{
			$image = NULL;
		}
		
		if ( $image !== Null ){
			
			$this->imageNew = imagecreatetruecolor( $this->widthNew, $this->heightNew );
			
			imagecopyresampled( $this->imageNew, $image, 0, 0, 0, 0, $this->widthNew, $this->heightNew, $info[0], $info[1]);
						
		}
			
	}
	
	/*
	 * Motion-Effekt erstellen 
	 * 
	 * @param	integer	$lines			Anzahl der Linien fr den Effekt
	 * @param	string	$fillcolor		Hintergrundfarbe
	 * @param	boolean	$effect			Motion-Effect mit abstufender Transparenz (true)
	 * @param	integer	$effect			Gleichbleibende Transparenz (wenn $effect = false) - 0-100
	 * 
	 */
	public function createMotion( $lines, $fillcolor, $effect = true, $trans = 70 ){
		
		$stepHigh = $this->heightNew - ($lines * 2);
		
		$stepWidth = $this->widthNew - ($lines * 2);
		
		$r = hexdec( substr( $fillcolor, 0, 2 ) );
		$g = hexdec( substr( $fillcolor, 2, 2 ) );
		$b = hexdec( substr( $fillcolor, 4, 2 ) );
		
		$image = imagecreatetruecolor( $this->widthNew, $this->heightNew );
		$color = imagecolorallocate($image, $r, $g, $b);
		imagefill($image, 0, 0, $color);
		
		imagecopyresampled( $image, $this->imageNew , 0, 0, 0, 0, $stepWidth, $stepHigh, $this->widthNew, $this->heightNew);
		imagecopyresampled( $this->imageNew, $image , 0, 0, 0, 0,$this->widthNew, $this->heightNew, $this->widthNew, $this->heightNew);
		
		for( $x = 0; $x < $lines; $x++ ){
			
			if ( $effect == true )
		        $opacity = max(0, 80-($x*(65 / $lines)));
		    else
		        $opacity = $trans;
		    
			for($y = 0; $y < $stepHigh; $y++)
				{
				imagecopymerge($this->imageNew, $image, $stepWidth+(2*$x) + 1, $y+(2*$x)+2, $stepWidth -1, $y+1, 1, 1, $opacity);
				}
			for($y = 0; $y < $stepWidth; $y++)
				{
				imagecopymerge($this->imageNew, $image, $y+(2*$x)+2,$stepHigh+(2*$x)+1, $y+1,$stepHigh-1,  1, 1, $opacity);
				}
		}
		
		imagedestroy( $image );
		
	}
	
	/*
	 * Bild speichern 
	 * 
	 * @param	string	$filedestination	Pfad fr neue Datei
	 * 
	 */
	public function createImage( $filedestination = NULL){
		
		imagejpeg($this->imageNew, $filedestination, 85);    
		
	}
	
}

?>